@@ -34,7 +34,7 @@
 
 //////////////////////////////////////////////////////////////
 
-u32bits get_ioa_addr_len(const ioa_addr* addr) {
+uint32_t get_ioa_addr_len(const ioa_addr* addr) {
   if(addr->ss.sa_family == AF_INET) return sizeof(struct sockaddr_in);
   else if(addr->ss.sa_family == AF_INET6) return sizeof(struct sockaddr_in6);
   return 0;
@@ -44,7 +44,7 @@ u32bits get_ioa_addr_len(const ioa_addr* addr) {
 
 void addr_set_any(ioa_addr *addr) {
 	if(addr)
-		ns_bzero(addr,sizeof(ioa_addr));
+		bzero(addr,sizeof(ioa_addr));
 }
 
 int addr_any(const ioa_addr* addr) {
@@ -59,7 +59,7 @@ int addr_any(const ioa_addr* addr) {
     else {
       size_t i;
       for(i=0;i<sizeof(addr->s6.sin6_addr);i++) 
-	if(((const s08bits*)&(addr->s6.sin6_addr))[i]) return 0;
+	if(((const char*)&(addr->s6.sin6_addr))[i]) return 0;
     }
   }
 
@@ -75,13 +75,13 @@ int addr_any_no_port(const ioa_addr* addr) {
   } else if(addr->ss.sa_family == AF_INET6) {
     size_t i;
     for(i=0;i<sizeof(addr->s6.sin6_addr);i++) 
-      if(((const s08bits*)(&(addr->s6.sin6_addr)))[i]) return 0;
+      if(((const char*)(&(addr->s6.sin6_addr)))[i]) return 0;
   }
 
   return 1;
 }
 
-u32bits hash_int32(u32bits a)
+uint32_t hash_int32(uint32_t a)
 {
 	a = a ^ (a>>4);
 	a = (a^0xdeadbeef) + (a<<5);
@@ -89,7 +89,7 @@ u32bits hash_int32(u32bits a)
 	return a;
 }
 
-u64bits hash_int64(u64bits a)
+uint64_t hash_int64(uint64_t a)
 {
 	a = a ^ (a>>4);
 	a = (a^0xdeadbeefdeadbeefLL) + (a<<5);
@@ -97,51 +97,51 @@ u64bits hash_int64(u64bits a)
 	return a;
 }
 
-u32bits addr_hash(const ioa_addr *addr)
+uint32_t addr_hash(const ioa_addr *addr)
 {
 	if(!addr)
 		return 0;
 
-	u32bits ret = 0;
+	uint32_t ret = 0;
 	if (addr->ss.sa_family == AF_INET) {
 		ret = hash_int32(addr->s4.sin_addr.s_addr + addr->s4.sin_port);
 	} else {
-		u64bits a[2];
-		ns_bcopy(&(addr->s6.sin6_addr), &a, sizeof(a));
-		ret = (u32bits)((hash_int64(a[0])<<3) + (hash_int64(a[1] + addr->s6.sin6_port)));
+		uint64_t a[2];
+		bcopy(&(addr->s6.sin6_addr), &a, sizeof(a));
+		ret = (uint32_t)((hash_int64(a[0])<<3) + (hash_int64(a[1] + addr->s6.sin6_port)));
 	}
 	return ret;
 }
 
-u32bits addr_hash_no_port(const ioa_addr *addr)
+uint32_t addr_hash_no_port(const ioa_addr *addr)
 {
 	if(!addr)
 		return 0;
 
-	u32bits ret = 0;
+	uint32_t ret = 0;
 	if (addr->ss.sa_family == AF_INET) {
 		ret = hash_int32(addr->s4.sin_addr.s_addr);
 	} else {
-		u64bits a[2];
-		ns_bcopy(&(addr->s6.sin6_addr), &a, sizeof(a));
-		ret = (u32bits)((hash_int64(a[0])<<3) + (hash_int64(a[1])));
+		uint64_t a[2];
+		bcopy(&(addr->s6.sin6_addr), &a, sizeof(a));
+		ret = (uint32_t)((hash_int64(a[0])<<3) + (hash_int64(a[1])));
 	}
 	return ret;
 }
 
 void addr_cpy(ioa_addr* dst, const ioa_addr* src) {
 	if(dst && src)
-		ns_bcopy(src,dst,sizeof(ioa_addr));
+		bcopy(src,dst,sizeof(ioa_addr));
 }
 
 void addr_cpy4(ioa_addr* dst, const struct sockaddr_in* src) {
 	if(src && dst)
-		ns_bcopy(src,dst,sizeof(struct sockaddr_in));
+		bcopy(src,dst,sizeof(struct sockaddr_in));
 }
 
 void addr_cpy6(ioa_addr* dst, const struct sockaddr_in6* src) {
 	if(src && dst)
-		ns_bcopy(src,dst,sizeof(struct sockaddr_in6));
+		bcopy(src,dst,sizeof(struct sockaddr_in6));
 }
 
 int addr_eq(const ioa_addr* a1, const ioa_addr *a2) {
@@ -183,7 +183,7 @@ int addr_eq_no_port(const ioa_addr* a1, const ioa_addr *a2) {
   return 0;
 }
 
-int make_ioa_addr(const u08bits* saddr0, int port, ioa_addr *addr) {
+int make_ioa_addr(const uint8_t* saddr0, int port, ioa_addr *addr) {
 
   if(!saddr0 || !addr) return -1;
 
@@ -203,7 +203,7 @@ int make_ioa_addr(const u08bits* saddr0, int port, ioa_addr *addr) {
 	  }
   }
 
-  ns_bzero(addr, sizeof(ioa_addr));
+  bzero(addr, sizeof(ioa_addr));
   if((len == 0)||
      (inet_pton(AF_INET, saddr, &addr->s4.sin_addr) == 1)) {
     addr->s4.sin_family = AF_INET;
@@ -247,7 +247,7 @@ int make_ioa_addr(const u08bits* saddr0, int port, ioa_addr *addr) {
 
     	if(addr_result->ai_family == family) {
     		if (addr_result->ai_family == AF_INET) {
-    			ns_bcopy(addr_result->ai_addr, addr, addr_result->ai_addrlen);
+    			bcopy(addr_result->ai_addr, addr, addr_result->ai_addrlen);
     			addr->s4.sin_port = nswap16(port);
 #if defined(TURN_HAS_SIN_LEN) /* tested when configured */
     			addr->s4.sin_len = sizeof(struct sockaddr_in);
@@ -255,7 +255,7 @@ int make_ioa_addr(const u08bits* saddr0, int port, ioa_addr *addr) {
     			found = 1;
     			break;
     		} else if (addr_result->ai_family == AF_INET6) {
-    			ns_bcopy(addr_result->ai_addr, addr, addr_result->ai_addrlen);
+    			bcopy(addr_result->ai_addr, addr, addr_result->ai_addrlen);
     			addr->s6.sin6_port = nswap16(port);
 #if defined(SIN6_LEN) /* this define is required by IPv6 if used */
     			addr->s6.sin6_len = sizeof(struct sockaddr_in6);
@@ -315,43 +315,43 @@ static char* get_addr_string_and_port(char* s0, int *port)
 	return NULL;
 }
 
-int make_ioa_addr_from_full_string(const u08bits* saddr, int default_port, ioa_addr *addr)
+int make_ioa_addr_from_full_string(const uint8_t* saddr, int default_port, ioa_addr *addr)
 {
 	if(!addr)
 		return -1;
 
 	int ret = -1;
 	int port = 0;
-	char* s = turn_strdup((const char*)saddr);
+	char* s = strdup((const char*)saddr);
 	char *sa = get_addr_string_and_port(s,&port);
 	if(sa) {
 		if(port<1)
 			port = default_port;
-		ret = make_ioa_addr((u08bits*)sa,port,addr);
+		ret = make_ioa_addr((uint8_t*)sa,port,addr);
 	}
-	turn_free(s,strlen(s)+1);
+	free(s);
 	return ret;
 }
 
-int addr_to_string(const ioa_addr* addr, u08bits* saddr)
+int addr_to_string(const ioa_addr* addr, uint8_t* saddr)
 {
 
 	if (addr && saddr) {
 
-		s08bits addrtmp[INET6_ADDRSTRLEN];
+		char addrtmp[INET6_ADDRSTRLEN];
 
 		if (addr->ss.sa_family == AF_INET) {
 			inet_ntop(AF_INET, &addr->s4.sin_addr, addrtmp, INET_ADDRSTRLEN);
 			if(addr_get_port(addr)>0)
-			  snprintf((s08bits*)saddr, MAX_IOA_ADDR_STRING, "%s:%d", addrtmp, addr_get_port(addr));
+			  snprintf((char*)saddr, MAX_IOA_ADDR_STRING, "%s:%d", addrtmp, addr_get_port(addr));
 			else
-			  strncpy((s08bits*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
+			  strncpy((char*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
 		} else if (addr->ss.sa_family == AF_INET6) {
 			inet_ntop(AF_INET6, &addr->s6.sin6_addr, addrtmp, INET6_ADDRSTRLEN);
 			if(addr_get_port(addr)>0)
-			  snprintf((s08bits*)saddr, MAX_IOA_ADDR_STRING, "[%s]:%d", addrtmp, addr_get_port(addr));
+			  snprintf((char*)saddr, MAX_IOA_ADDR_STRING, "[%s]:%d", addrtmp, addr_get_port(addr));
 			else
-			  strncpy((s08bits*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
+			  strncpy((char*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
 		} else {
 			return -1;
 		}
@@ -362,19 +362,19 @@ int addr_to_string(const ioa_addr* addr, u08bits* saddr)
 	return -1;
 }
 
-int addr_to_string_no_port(const ioa_addr* addr, u08bits* saddr)
+int addr_to_string_no_port(const ioa_addr* addr, uint8_t* saddr)
 {
 
 	if (addr && saddr) {
 
-		s08bits addrtmp[MAX_IOA_ADDR_STRING];
+		char addrtmp[MAX_IOA_ADDR_STRING];
 
 		if (addr->ss.sa_family == AF_INET) {
 			inet_ntop(AF_INET, &addr->s4.sin_addr, addrtmp, INET_ADDRSTRLEN);
-			strncpy((s08bits*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
+			strncpy((char*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
 		} else if (addr->ss.sa_family == AF_INET6) {
 			inet_ntop(AF_INET6, &addr->s6.sin6_addr, addrtmp, INET6_ADDRSTRLEN);
-			strncpy((s08bits*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
+			strncpy((char*)saddr, addrtmp, MAX_IOA_ADDR_STRING);
 		} else {
 			return -1;
 		}
@@ -425,11 +425,11 @@ int addr_less_eq(const ioa_addr* addr1, const ioa_addr* addr2) {
   else {
     if(addr1->ss.sa_family != addr2->ss.sa_family) return (addr1->ss.sa_family < addr2->ss.sa_family);
     else if(addr1->ss.sa_family == AF_INET) {
-      return ((u32bits)nswap32(addr1->s4.sin_addr.s_addr) <= (u32bits)nswap32(addr2->s4.sin_addr.s_addr));
+      return ((uint32_t)nswap32(addr1->s4.sin_addr.s_addr) <= (uint32_t)nswap32(addr2->s4.sin_addr.s_addr));
     } else if(addr1->ss.sa_family == AF_INET6) {
       int i;
       for(i=0;i<16;i++) {
-	if((u08bits)(((const s08bits*)&(addr1->s6.sin6_addr))[i]) > (u08bits)(((const s08bits*)&(addr2->s6.sin6_addr))[i])) 
+	if((uint8_t)(((const char*)&(addr1->s6.sin6_addr))[i]) > (uint8_t)(((const char*)&(addr2->s6.sin6_addr))[i])) 
 	  return 0;
       }
       return 1;
@@ -465,10 +465,10 @@ int ioa_addr_is_multicast(ioa_addr *addr)
 {
 	if(addr) {
 		if(addr->ss.sa_family == AF_INET) {
-			const u08bits *u = ((const u08bits*)&(addr->s4.sin_addr));
+			const uint8_t *u = ((const uint8_t*)&(addr->s4.sin_addr));
 			return (u[0] > 223);
 		} else if(addr->ss.sa_family == AF_INET6) {
-			u08bits u = ((const u08bits*)&(addr->s6.sin6_addr))[0];
+			uint8_t u = ((const uint8_t*)&(addr->s6.sin6_addr))[0];
 			return (u == 255);
 		}
 	}
@@ -479,10 +479,10 @@ int ioa_addr_is_loopback(ioa_addr *addr)
 {
 	if(addr) {
 		if(addr->ss.sa_family == AF_INET) {
-			const u08bits *u = ((const u08bits*)&(addr->s4.sin_addr));
+			const uint8_t *u = ((const uint8_t*)&(addr->s4.sin_addr));
 			return (u[0] == 127);
 		} else if(addr->ss.sa_family == AF_INET6) {
-			const u08bits *u = ((const u08bits*)&(addr->s6.sin6_addr));
+			const uint8_t *u = ((const uint8_t*)&(addr->s6.sin6_addr));
 			if(u[7] == 1) {
 				int i;
 				for(i=0;i<7;++i) {
@@ -509,10 +509,10 @@ static size_t msz = 0;
 void ioa_addr_add_mapping(ioa_addr *apub, ioa_addr *apriv)
 {
 	size_t new_size = msz + sizeof(ioa_addr*);
-	public_addrs = (ioa_addr**)turn_realloc(public_addrs, msz, new_size);
-	private_addrs = (ioa_addr**)turn_realloc(private_addrs, msz, new_size);
-	public_addrs[mcount]=(ioa_addr*)turn_malloc(sizeof(ioa_addr));
-	private_addrs[mcount]=(ioa_addr*)turn_malloc(sizeof(ioa_addr));
+	public_addrs = (ioa_addr**)realloc(public_addrs, new_size);
+	private_addrs = (ioa_addr**)realloc(private_addrs, new_size);
+	public_addrs[mcount]=(ioa_addr*)malloc(sizeof(ioa_addr));
+	private_addrs[mcount]=(ioa_addr*)malloc(sizeof(ioa_addr));
 	addr_cpy(public_addrs[mcount],apub);
 	addr_cpy(private_addrs[mcount],apriv);
 	++mcount;
